# Ace Editor

<badges>[![version](https://img.shields.io/pypi/v/aceditor.svg)](https://pypi.org/project/aceditor/)
[![license](https://img.shields.io/pypi/l/aceditor.svg)](https://pypi.org/project/aceditor/)
[![pyversions](https://img.shields.io/pypi/pyversions/aceditor.svg)](https://pypi.org/project/aceditor/)  
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![powered](https://img.shields.io/badge/Powered%20by-UTF8-red.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>ACE full stack editor with JavaScript and Python CGI.  
Demo: [https://foxe6.github.io/aceditor/](https://foxe6.github.io/aceditor/) </i>

# Hierarchy

```
aceditor
```

# Example
See [aceditor/example](aceditor/example).
